@@ -9,18 +9,39 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\TestDox;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @covers \SebastianBergmann\Type\MixedType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\CallableType
- * @uses \SebastianBergmann\Type\GenericObjectType
- * @uses \SebastianBergmann\Type\SimpleType
- */
+#[CoversClass(MixedType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(CallableType::class)]
+#[UsesClass(GenericObjectType::class)]
+#[UsesClass(SimpleType::class)]
+#[Small]
 final class MixedTypeTest extends TestCase
 {
+    /**
+     * @return non-empty-list<array{0: non-empty-string}>
+     */
+    public static function assignableTypes(): array
+    {
+        return [
+            ['array'],
+            ['bool'],
+            ['callable'],
+            ['int'],
+            ['float'],
+            ['null'],
+            ['object'],
+            ['resource'],
+            ['string'],
+        ];
+    }
+
     public function testHasName(): void
     {
         $type = new MixedType;
@@ -42,11 +63,8 @@ final class MixedTypeTest extends TestCase
         $this->assertTrue($type->allowsNull());
     }
 
-    /**
-     * @dataProvider typeProvider
-     *
-     * @testdox $otherType can be assigned to mixed
-     */
+    #[DataProvider('assignableTypes')]
+    #[TestDox('$otherType can be assigned to mixed')]
     public function testOtherTypeCanBeAssigned(string $otherType): void
     {
         $type = new MixedType;
@@ -54,39 +72,52 @@ final class MixedTypeTest extends TestCase
         $this->assertTrue($type->isAssignable(Type::fromName($otherType, false)));
     }
 
-    public function typeProvider(): array
-    {
-        return [
-            ['array'],
-            ['bool'],
-            ['callable'],
-            ['int'],
-            ['float'],
-            ['null'],
-            ['object'],
-            ['resource'],
-            ['string'],
-        ];
-    }
-
     public function testCanBeQueriedForType(): void
     {
         $type = new MixedType;
 
-        $this->assertFalse($type->isCallable());
-        $this->assertFalse($type->isFalse());
-        $this->assertFalse($type->isGenericObject());
-        $this->assertFalse($type->isIntersection());
-        $this->assertFalse($type->isIterable());
         $this->assertTrue($type->isMixed());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isCallable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isFalse());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isGenericObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIntersection());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIterable());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isNever());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isNull());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isObject());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isSimple());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isStatic());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isTrue());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isUnion());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isUnknown());
+
+        /** @phpstan-ignore method.impossibleType */
         $this->assertFalse($type->isVoid());
     }
 }
