@@ -10,39 +10,33 @@
 namespace SebastianBergmann\Type;
 
 use function strtolower;
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use SebastianBergmann\Type\TestFixture\ChildClass;
 use SebastianBergmann\Type\TestFixture\ParentClass;
 
-/**
- * @covers \SebastianBergmann\Type\ObjectType
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\TypeName
- */
+#[CoversClass(ObjectType::class)]
+#[CoversClass(Type::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class ObjectTypeTest extends TestCase
 {
-    /**
-     * @var ObjectType
-     */
-    private $childClass;
-
-    /**
-     * @var ObjectType
-     */
-    private $parentClass;
+    private ObjectType $childClass;
+    private ObjectType $parentClass;
 
     protected function setUp(): void
     {
         $this->childClass = new ObjectType(
             TypeName::fromQualifiedName(ChildClass::class),
-            false
+            false,
         );
 
         $this->parentClass = new ObjectType(
             TypeName::fromQualifiedName(ParentClass::class),
-            false
+            false,
         );
     }
 
@@ -74,13 +68,15 @@ final class ObjectTypeTest extends TestCase
     public function testClassFromOneNamespaceIsNotAssignableToClassInOtherNamespace(): void
     {
         $classFromNamespaceA = new ObjectType(
+            /** @phpstan-ignore class.notFound */
             TypeName::fromQualifiedName(\someNamespaceA\NamespacedClass::class),
-            false
+            false,
         );
 
         $classFromNamespaceB = new ObjectType(
+            /** @phpstan-ignore class.notFound */
             TypeName::fromQualifiedName(\someNamespaceB\NamespacedClass::class),
-            false
+            false,
         );
         $this->assertFalse($classFromNamespaceA->isAssignable($classFromNamespaceB));
     }
@@ -89,7 +85,7 @@ final class ObjectTypeTest extends TestCase
     {
         $classLowercased = new ObjectType(
             TypeName::fromQualifiedName(strtolower(ParentClass::class)),
-            false
+            false,
         );
 
         $this->assertTrue($this->parentClass->isAssignable($classLowercased));
@@ -99,7 +95,7 @@ final class ObjectTypeTest extends TestCase
     {
         $someClass = new ObjectType(
             TypeName::fromQualifiedName(ParentClass::class),
-            true
+            true,
         );
         $this->assertTrue($someClass->isAssignable(Type::fromValue(null, true)));
     }
@@ -108,7 +104,7 @@ final class ObjectTypeTest extends TestCase
     {
         $someClass = new ObjectType(
             TypeName::fromQualifiedName(ParentClass::class),
-            false
+            false,
         );
 
         $this->assertFalse($someClass->isAssignable(Type::fromValue(null, true)));
@@ -118,7 +114,7 @@ final class ObjectTypeTest extends TestCase
     {
         $someClass = new ObjectType(
             TypeName::fromQualifiedName(ParentClass::class),
-            false
+            false,
         );
 
         $this->assertFalse($someClass->allowsNull());
@@ -128,7 +124,7 @@ final class ObjectTypeTest extends TestCase
     {
         $someClass = new ObjectType(
             TypeName::fromQualifiedName(ParentClass::class),
-            true
+            true,
         );
 
         $this->assertTrue($someClass->allowsNull());
@@ -141,6 +137,7 @@ final class ObjectTypeTest extends TestCase
 
     public function testCanBeQueriedForType(): void
     {
+        $this->assertTrue($this->childClass->isObject());
         $this->assertFalse($this->childClass->isCallable());
         $this->assertFalse($this->childClass->isFalse());
         $this->assertFalse($this->childClass->isGenericObject());
@@ -149,7 +146,6 @@ final class ObjectTypeTest extends TestCase
         $this->assertFalse($this->childClass->isMixed());
         $this->assertFalse($this->childClass->isNever());
         $this->assertFalse($this->childClass->isNull());
-        $this->assertTrue($this->childClass->isObject());
         $this->assertFalse($this->childClass->isSimple());
         $this->assertFalse($this->childClass->isStatic());
         $this->assertFalse($this->childClass->isTrue());
