@@ -9,31 +9,28 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
 use stdClass;
 
-/**
- * @covers \SebastianBergmann\Type\Type
- *
- * @uses \SebastianBergmann\Type\CallableType
- * @uses \SebastianBergmann\Type\GenericObjectType
- * @uses \SebastianBergmann\Type\IterableType
- * @uses \SebastianBergmann\Type\NeverType
- * @uses \SebastianBergmann\Type\ObjectType
- * @uses \SebastianBergmann\Type\SimpleType
- * @uses \SebastianBergmann\Type\TypeName
- */
+#[CoversClass(Type::class)]
+#[UsesClass(CallableType::class)]
+#[UsesClass(GenericObjectType::class)]
+#[UsesClass(IterableType::class)]
+#[UsesClass(NeverType::class)]
+#[UsesClass(ObjectType::class)]
+#[UsesClass(SimpleType::class)]
+#[UsesClass(TypeName::class)]
+#[Small]
 final class TypeTest extends TestCase
 {
     /**
-     * @dataProvider valuesToNullableType
+     * @return non-empty-array<string, array{0: mixed, 1: bool, 2: Type}>
      */
-    public function testTypeMappingFromValue($value, bool $allowsNull, Type $expectedType): void
-    {
-        $this->assertEquals($expectedType, Type::fromValue($value, $allowsNull));
-    }
-
-    public function valuesToNullableType(): array
+    public static function valuesToNullableType(): array
     {
         return [
             '?null'          => [null, true, new NullType],
@@ -50,14 +47,9 @@ final class TypeTest extends TestCase
     }
 
     /**
-     * @dataProvider typeFromName
+     * @return non-empty-array<string, array{0: Type, 1: non-empty-string, 2: bool}>
      */
-    public function testCanBeCreatedFromName($expectedType, string $typeName, bool $allowsNull): void
-    {
-        $this->assertEquals($expectedType, Type::fromName($typeName, $allowsNull));
-    }
-
-    public function typeFromName(): array
+    public static function namesToTypes(): array
     {
         return [
             '?void'             => [new VoidType, 'void', true],
@@ -86,22 +78,20 @@ final class TypeTest extends TestCase
             '?callable'         => [new CallableType(true), 'callable', true],
             'iterable'          => [new IterableType(false), 'iterable', false],
             '?iterable'         => [new IterableType(true), 'iterable', true],
+            'mixed'             => [new MixedType, 'mixed', false],
+            'never'             => [new NeverType, 'never', false],
         ];
     }
 
-    /**
-     * @requires PHP < 8.1
-     */
-    public function testMapsFromClassNamedNever(): void
+    #[DataProvider('valuesToNullableType')]
+    public function testTypeMappingFromValue(mixed $value, bool $allowsNull, Type $expectedType): void
     {
-        $this->assertTrue(Type::fromName('never', false)->isObject());
+        $this->assertEquals($expectedType, Type::fromValue($value, $allowsNull));
     }
 
-    /**
-     * @requires PHP >= 8.1
-     */
-    public function testMapsFromNever(): void
+    #[DataProvider('namesToTypes')]
+    public function testTypeMappingFromName(Type $expectedType, string $typeName, bool $allowsNull): void
     {
-        $this->assertTrue(Type::fromName('never', false)->isNever());
+        $this->assertEquals($expectedType, Type::fromName($typeName, $allowsNull));
     }
 }
