@@ -9,33 +9,22 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @covers \SebastianBergmann\Type\Type
- * @covers \SebastianBergmann\Type\UnknownType
- */
+#[CoversClass(UnknownType::class)]
+#[CoversClass(Type::class)]
+#[Small]
 final class UnknownTypeTest extends TestCase
 {
-    /**
-     * @var UnknownType
-     */
-    private $type;
-
-    protected function setUp(): void
-    {
-        $this->type = new UnknownType;
-    }
+    private UnknownType $type;
 
     /**
-     * @dataProvider assignableTypes
+     * @return non-empty-list<array{0: Type}>
      */
-    public function testIsAssignable(Type $assignableType): void
-    {
-        $this->assertTrue($this->type->isAssignable($assignableType));
-    }
-
-    public function assignableTypes(): array
+    public static function assignableTypes(): array
     {
         return [
             [new SimpleType('int', false)],
@@ -47,6 +36,17 @@ final class UnknownTypeTest extends TestCase
         ];
     }
 
+    protected function setUp(): void
+    {
+        $this->type = new UnknownType;
+    }
+
+    #[DataProvider('assignableTypes')]
+    public function testIsAssignable(Type $assignableType): void
+    {
+        $this->assertTrue($this->type->isAssignable($assignableType));
+    }
+
     public function testAllowsNull(): void
     {
         $this->assertTrue($this->type->allowsNull());
@@ -64,6 +64,7 @@ final class UnknownTypeTest extends TestCase
 
     public function testCanBeQueriedForType(): void
     {
+        $this->assertTrue($this->type->isUnknown());
         $this->assertFalse($this->type->isCallable());
         $this->assertFalse($this->type->isFalse());
         $this->assertFalse($this->type->isGenericObject());
@@ -77,7 +78,6 @@ final class UnknownTypeTest extends TestCase
         $this->assertFalse($this->type->isStatic());
         $this->assertFalse($this->type->isTrue());
         $this->assertFalse($this->type->isUnion());
-        $this->assertTrue($this->type->isUnknown());
         $this->assertFalse($this->type->isVoid());
     }
 }
