@@ -9,30 +9,20 @@
  */
 namespace SebastianBergmann\Type;
 
+use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
-/**
- * @covers \SebastianBergmann\Type\Type
- * @covers \SebastianBergmann\Type\VoidType
- */
+#[CoversClass(VoidType::class)]
+#[CoversClass(Type::class)]
+#[Small]
 final class VoidTypeTest extends TestCase
 {
-    public function testHasName(): void
-    {
-        $this->assertSame('void', (new VoidType)->name());
-    }
-
     /**
-     * @dataProvider assignableTypes
+     * @return non-empty-list<array{0: Type}>
      */
-    public function testIsAssignable(Type $assignableType): void
-    {
-        $type = new VoidType;
-
-        $this->assertTrue($type->isAssignable($assignableType));
-    }
-
-    public function assignableTypes(): array
+    public static function assignableTypes(): array
     {
         return [
             [new VoidType],
@@ -40,16 +30,9 @@ final class VoidTypeTest extends TestCase
     }
 
     /**
-     * @dataProvider notAssignableTypes
+     * @return non-empty-list<array{0: Type}>
      */
-    public function testIsNotAssignable(Type $assignableType): void
-    {
-        $type = new VoidType;
-
-        $this->assertFalse($type->isAssignable($assignableType));
-    }
-
-    public function notAssignableTypes(): array
+    public static function notAssignableTypes(): array
     {
         return [
             [new SimpleType('int', false)],
@@ -60,6 +43,27 @@ final class VoidTypeTest extends TestCase
         ];
     }
 
+    public function testHasName(): void
+    {
+        $this->assertSame('void', (new VoidType)->name());
+    }
+
+    #[DataProvider('assignableTypes')]
+    public function testIsAssignable(Type $assignableType): void
+    {
+        $type = new VoidType;
+
+        $this->assertTrue($type->isAssignable($assignableType));
+    }
+
+    #[DataProvider('notAssignableTypes')]
+    public function testIsNotAssignable(Type $assignableType): void
+    {
+        $type = new VoidType;
+
+        $this->assertFalse($type->isAssignable($assignableType));
+    }
+
     public function testNotAllowNull(): void
     {
         $type = new VoidType;
@@ -71,20 +75,48 @@ final class VoidTypeTest extends TestCase
     {
         $type = new VoidType;
 
-        $this->assertFalse($type->isCallable());
-        $this->assertFalse($type->isFalse());
-        $this->assertFalse($type->isGenericObject());
-        $this->assertFalse($type->isIntersection());
-        $this->assertFalse($type->isIterable());
-        $this->assertFalse($type->isMixed());
-        $this->assertFalse($type->isNever());
-        $this->assertFalse($type->isNull());
-        $this->assertFalse($type->isObject());
-        $this->assertFalse($type->isSimple());
-        $this->assertFalse($type->isStatic());
-        $this->assertFalse($type->isTrue());
-        $this->assertFalse($type->isUnion());
-        $this->assertFalse($type->isUnknown());
         $this->assertTrue($type->isVoid());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isCallable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isFalse());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isGenericObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIntersection());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isIterable());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isMixed());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNever());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isNull());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isObject());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isSimple());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isStatic());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isTrue());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isUnion());
+
+        /** @phpstan-ignore method.impossibleType */
+        $this->assertFalse($type->isUnknown());
     }
 }
